@@ -1,17 +1,15 @@
 package Google::OAuth2::Client::Simple;
 # ABSTRACT: OAuth lib for Google OAuth 2.0
-$Google::OAuth2::Client::Simple::VERSION = '0.003';
-use strict;
-use warnings;
-
+$Google::OAuth2::Client::Simple::VERSION = '0.004';
 use Carp;
+use Cpanel::JSON::XS;
 use Furl;
 use Moo;
 use URI;
 
 =head1 NAME
 
-Google::OAuth2::Client::Simple
+Google::OAuth2::Client::Simple - Client for Google OAuth2.
 
 =head1 SYNOPSIS
 
@@ -32,7 +30,7 @@ Google::OAuth2::Client::Simple
 
     then in your 'redirect_uri' route:
     my $token_ref = $google_client->exchange_code_for_token($self->param('code'), $self->param('state'));
-    $app->access_token($token_ref->{access_token}); # set the access token in your app, it lasts for an hour
+    $app->access_token($token_ref->{access_token}); # set the access token somewhere (maybe in cache?), it lasts for an hour
 
 =head1 DESCRIPTION
 
@@ -108,7 +106,7 @@ has ua => (
     },
 );
 
-=head2 $g_oauth->request_user_consent
+=head2 request_user_consent
 
 Returns a Furl::Response, the contents of which will contain Googles
 sign in form. Once the user signs in they will be shown a list of
@@ -154,7 +152,7 @@ sub request_user_consent {
     return $response;
 }
 
-=head2 $g_oauth->exchange_code_for_token($code)
+=head2 exchange_code_for_token($code)
 
 Returns a I<HashRef> of token data which looks like:
 
@@ -204,10 +202,10 @@ sub exchange_code_for_token {
         content => \%params
     );
 
-    return JSON::from_json($response->decoded_content());
+    return decode_json($response->decoded_content());
 }
 
-=head2 $g_oauth->refresh_token($access_token)
+=head2 refresh_token($refresh_token)
 
 For use when you require offline access.
 
@@ -242,10 +240,10 @@ sub refresh_token {
         content => \%params
     );
 
-    return JSON::from_json($response->decoded_content());
+    return decode_json($response->decoded_content());
 }
 
-=head2 $g_oauth->revoke_token($access_token)
+=head2 revoke_token($access_token)
 
 Revokes the access token on Google on behalf of the user.
 
